@@ -1,14 +1,11 @@
 from __future__ import annotations
 
 import re
-import typing as t
 from pathlib import Path
 
 from .. import helpers
-from ..step import Step
+from ..core import Context
 from .parser import process
-if t.TYPE_CHECKING:
-    from ..context import Context
 
 
 def anchovy_css_step(path: Path, match: re.Match[str], context: Context):
