@@ -1,7 +1,7 @@
 import re
 from pathlib import Path
 
-from .context import Context
+from .core import Context
 
 
 def trim_ext_prefix(path: Path, match: re.Match[str]):
@@ -14,6 +14,11 @@ def trim_ext_prefix(path: Path, match: re.Match[str]):
 
 
 def to_dir(dest: Path, context: Context, path: Path, match: re.Match[str], ext: str | None = None):
+    """
+    Get a version of @path as a child of @dest. If @ext is specified, it will
+    replace the extension on @path. @match will be consulted to check for
+    explicitly defined extension information for @path.
+    """
     path = trim_ext_prefix(path, match) if ext else path
 
     rel = path.relative_to(
@@ -30,8 +35,18 @@ def to_dir(dest: Path, context: Context, path: Path, match: re.Match[str], ext:
 
 
 def to_output(context: Context, path: Path, match: re.Match[str], ext: str | None = None):
+    """
+    Get a version of @path as a child of @context.output_dir. If @ext is
+    specified, it will replace the extension on @path. @match will be consulted
+    to check for explicitly defined extension information for @path.
+    """
     return to_dir(context['output_dir'], context, path, match, ext)
 
 
 def to_working(context: Context, path: Path, match: re.Match[str], ext: str | None = None):
+    """
+    Get a version of @path as a child of @context.working_dir. If @ext is
+    specified, it will replace the extension on @path. @match will be consulted
+    to check for explicitly defined extension information for @path.
+    """
     return to_dir(context['working_dir'], context, path, match, ext)
