@@ -8,18 +8,24 @@ import commonmark
 import commonmark.render.renderer
 from jinja2 import Environment, FileSystemLoader, select_autoescape
 
-from .step import Step
-if t.TYPE_CHECKING:
-    from .context import Context
+from . import helpers
+from .core import Context, Step
 
 
 class JinjaRenderStep(Step):
+    """
+    Abstract base class for Steps using Jinja rendering.
+    """
     env: Environment
 
     def __init__(self, env: Environment | None):
         self._temporary_env = env
 
     def bind(self, context: Context):
+        """
+        Bind this Step to a specific context. Also initializes a Jinja
+        environment if none is set up already.
+        """
         super().bind(context)
 
         if self._temporary_env:
@@ -39,6 +45,12 @@ class JinjaRenderStep(Step):
 
 
 class JinjaMarkdownStep(JinjaRenderStep):
+    """
+    A Step for rendering Markdown using Jinja templates. Parses according to
+    CommonMark and Renders to HTML by default.
+    """
+    encoding = 'utf-8'
+
     def __init__(self,
                  default_template: str | None = None,
                  md_parser: commonmark.Parser | None = None,
@@ -50,11 +62,11 @@ class JinjaMarkdownStep(JinjaRenderStep):
         self.md_renderer = md_renderer or commonmark.HtmlRenderer()
 
     def __call__(self, path: Path, match: re.Match[str]) -> t.Iterable[Path]:
-        meta, content = self.extract_metadata(path.read_text())
+        meta, content = self.extract_metadata(path.read_text(self.encoding))
         ast = self.md_parser.parse(content.strip())
         meta |= {'rendered_markdown': self.md_renderer.render(ast).strip()}
 
-        target_path = self.context['output_dir'] / path.relative_to(self.context['input_dir']).with_suffix('.html')
+        target_path = helpers.to_output(self.context, path, match, '.html')
 
         yield self.render_template(
             meta.get('template', self.default_template),
@@ -63,6 +75,9 @@ class JinjaMarkdownStep(JinjaRenderStep):
         )
 
     def extract_metadata(self, text: str):
+        """
+        Read metadata from the front of a markdown-formatted text.
+        """
         meta = {}
         lines = text.splitlines()
 
